Accelerating Barnes-Hut t-SNE Algorithm by Efficient Parallelization on Multi-Core CPUs
Source-linked · authorship unverifiedThis paper presents an accelerated version of the Barnes-Hut t-SNE algorithm for multi-core CPUs, employing cache optimizations, SIMD, parallelization, and improved multithreaded execution. The new implementation, Acc-t-SNE, achieves up to 261x and 4x speedups compared to scikit-…